/**
 * POST api for engagement event tracking
 * The engagement_token will be output to the page as a Drupal.settings variable
 * The token ensures that all data tracked is valid
 * action is the action to take.. you can do these actions:
 *  event_track
 *  event_get
 * the ACTION is what will determine what vars to send to the API callback
 * Drupal.engagement.track('user_click','this_button');
 * var count = Drupal.engagement.get('user_click','this_button');
 */
(function ($) {

  Drupal.engagement = {
    api_url : "/engagement/api/"
  }

  /**
   * Send event data to the server
   * @param string event_name
   * @param string event_value
   * @param event_data
   */
  Drupal.engagement.track = function(event_name, event_value, event_data, uid){
    $.ajax({
      url:Drupal.engagement.api_url + Drupal.engagement.token(),
      data:'action=event_track&event_name='+event_name+
      '&event_value='+event_value+'&event_data='+event_data+
      '&uid='+uid,
      type:"POST"
    });
    if(Drupal.engagement.ga){
      _gaq.push(['_trackEvent', event_name, event_value, event_data]);
    }
  }

  /**
   * Returns the value/data associated with the event
   * @param string action
   *   An action can be to get value, data, count, count_total
   */
  Drupal.engagement.get = function(action, event_id, event_name, event_value, uid){
    var result = null;
    if(action == 'value'){
      action = 'event_get_value';
    }else if(action == 'data'){
      action = 'event_get_data';
    }else if(action == 'count'){
      action = 'event_count';
    }else if(action == 'count_total'){
      action = 'event_count_total';
    }else if(action == 'delete'){
      action = 'event_delete';
    }
    $.ajax({
      url:Drupal.engagement.api_url + Drupal.engagement.token(),
      data:'action='+action+'&event_name='+event_name+
      '&event_value='+event_value+'&uid='+uid+'&event_id='+event_id,
      type:"POST",
      async:false,
      success:function(val){
        result = val;
      }
    });
    return result;
  }

  /**
   * Returns the engagement token value
   */
  Drupal.engagement.token = function(){
    return String(Drupal.settings.engagement_token_value);
  }

  /**
   * Returns true if Google analytics is enabled
   */
  Drupal.engagement.ga = function(){
    return Drupal.settings.engagement_analytics_ga;
  }

  /**
   * Returns true if Site Catalyst is enabled
   */
  Drupal.engagement.sc = function(){
    return Drupal.settings.engagement_analytics_sc;
  }

  Drupal.behaviors.engagement = {
    attach:function(context,settings){}
  }

}(jQuery));
